Gross Primary Productivity (GPP)
PEPRMT_GPP.RdGross Primary Productivity (GPP) module of the PEPRMT model (v1.0). Default values were determined via MCMC Bayesian fitting (Oikawa et al. 2023).
Usage
PEPRMT_GPP(
data,
a0 = 0.7479271,
a1 = 1.0497113,
Ha = 149.468171 + 30,
Hd = 94.4532674 + 100,
T_opt_GPP = 25 + 274.15
)Arguments
- data
Data frame containing 15 required columns used as model inputs. See Details for expected column structure.
- a0
Empirical intercept parameter for the fPAR scaling function (unitless).
- a1
Empirical slope parameter for the fPAR scaling function (unitless).
- Ha
Activation energy governing the temperature response of photosynthesis for general crop-type vegetation (kJ mol^-1). Controls the rate of increase in GPP with temperature below the thermal optimum.
- Hd
Deactivation energy controlling the decline in photosynthesis above the thermal optimum (kJ mol^-1). Determines the rate of decrease in GPP at high temperatures.
- T_opt_GPP
Temperature optimum for GPP
Value
Updated dataframe containing:
- GPP
gross primary productivity (g C CO2 m^-2 d^-1)
- APAR
absorbed photosynthetically active radiation (umol m^-2 d^-1)
Details
Runs the PEPRMT gross primary productivity module for freshwater peatlands or tidal wetlands at a daily time step.
The PEPRMT model was originally parameterized for restored freshwater wetlands in the Sacramento–San Joaquin River Delta, California, USA (Oikawa et al. 2017) and later updated for tidal wetlands (Oikawa et al. 2023).
Modules are intended to be run sequentially: PEPRMT_GPP, then PEPRMT_Reco, then PEPRMT_CH4.
All variables are expected at a daily time step.
This model predicts GPP using a light use efficiency equation GPP can be predicted using leaf area index (LAI) or a greenness index from Phenocam data or remote sensing such as EVI or NDVI PEPRMT-Tidal applied in Oikawa et al. 2023 uses EVI from Landsat
Required data columns:
Continuous day of year
Discontinuous day of year
Year
Air temperature (°C)
Water table depth (cm)
PAR (µmol m^-2 d^-1)
Leaf Area Index
Greenness Index
FPAR flag
Light Use Efficiency
Wetland age (years)
Salinity (ppt)
NO3 (mg L^-1)
Soil organic matter (g C m^-3)
Site identifier
References
Oikawa, P. Y., Jenerette, G. D., Knox, S. H., Sturtevant, C., Verfaillie, J., Dronova, I., Poindexter, C. M., Eichelmann, E., & Baldocchi, D. D. (2017). Evaluation of a hierarchy of models reveals importance of substrate limitation for predicting carbon dioxide and methane exchange in restored wetlands. Journal of Geophysical Research: Biogeosciences, 122(1), 145–167. https://doi.org/10.1002/2016JG003438
Oikawa, P. Y., Sihi, D., Forbrich, I., Fluet-Chouinard, E., Najarro, M., Thomas, O., Shahan, J., Arias-Ortiz, A., Russell, S., Knox, S. H., McNicol, G., Wolfe, J., Windham-Myers, L., Stuart-Haentjens, E., Bridgham, S. D., Needelman, B., Vargas, R., Schäfer, K., Ward, E. J., Megonigal, P., & Holmquist, J. (2024). A New Coupled Biogeochemical Modeling Approach Provides Accurate Predictions of Methane and Carbon Dioxide Fluxes Across Diverse Tidal Wetlands. Journal of Geophysical Research: Biogeosciences, 129(10), e2023JG007943. https://doi.org/10.1029/2023JG007943